@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
 our $DATE = '2015-02-07'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -19,7 +19,7 @@ sub import {
     my $caller = caller();
     my $i = 0;
     while ($i < @_) {
-        if ($_[$i] eq 'system' || $_[$i] eq 'backtick') {
+        if ($_[$i] eq 'system' || $_[$i] eq 'backtick' || $_[$i] eq 'import') {
             no strict 'refs';
             *{"$caller\::$_[$i]"} = \&{$_[$i]};
         } elsif ($_[$i] =~ /\A-(.+)/) {
@@ -131,7 +131,7 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.05 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-02-07.
+This document describes version 0.06 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-02-07.
 
 =head1 SYNOPSIS
 
